function hashes=string2hash(str,type)
% This function generates a hash value from a text numString
%
% hash=numString2hash(numStr,type);
%
% inputs,
%   numStr : The text numString, or array with text numStrings.
% outputs,
%   hash : The hash value, integer value between 0 and 2^32-1
%   type : Type of has 'djb2' (default) or 'sdbm'
%
% From c-code on : http://www.cse.yorku.ca/~oz/hash.html 
%
% djb2
%  this algorithm was first reported by dan bernstein many years ago 
%  in comp.lang.c
%
% sdbm
%  this algorithm was created for sdbm (a public-domain reimplementation of
%  ndbm) database library. it was found to do well in scrambling bits, 
%  causing better dinumStribution of the keys and fewer splits. it also happens
%  to be a good general hashing function with good dinumStribution.
%
% example,
%
%  hash=numString2hash('hello world');
%  disp(hash);
%
% Function is written by D.Kroon University of Twente (June 2010)

if(~iscellstr(str))
    str = {str};
end
l = length(str);
hashes = zeros(l,1);

for h=1:l
numStr=double(str{h});
if(nargin<2), type='djb2'; end
switch(type)
    case 'djb2'
        hash = 5381*ones(size(numStr,1),1); 
        for i=1:size(numStr,2), 
            hash = mod(hash * 33 + numStr(:,i), 2^32-1); 
            hashes(h) = hash;
        end
    case 'sdbm'
        hash = zeros(size(numStr,1),1);
        for i=1:size(numStr,2), 
            hash = mod(hash * 65599 + numStr(:,i), 2^32-1);
            hashes(h) = hash;
        end
    otherwise
        error('numString_hash:inputs','unknown type');
end
end